:py:mod:`save_pandas_df_com`
============================

.. py:module:: save_pandas_df_com


Module Contents
---------------

.. py:data:: current_dir
   

   

.. py:data:: current_dir
   

   

.. py:data:: Exec
   

   Properties of the generated Node


.. py:data:: BaseName
   :annotation: = Save Pandas DF

   

.. py:data:: NodeAttributeNames
   :annotation: = ['Parameters', 'Row In']

   

.. py:data:: NodeAttributeType
   :annotation: = ['Static', 'Input']

   

.. py:data:: ParameterNames
   :annotation: = ['Visualisation', 'Columns', 'File Name', 'Overwrite']

   

.. py:data:: ParameterTypes
   :annotation: = ['bool', 'str', 'str', 'bool']

   

.. py:data:: ParametersDefaultValues
   :annotation: = [False, 'Column 1, Column 2', 'C:\\test.df', False]

   

.. py:data:: WorkerDefaultExecutable
   

   

.. py:data:: save_pandas_df_com
   

   

